/*
 *   This file is part of Clinica.
 *
 *   Clinica is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   Clinica is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with Clinica.  If not, see <http://www.gnu.org/licenses/>.
 *
 *   Authors: Leonardo Robol <leo@robol.it>
 */

/* The Unity lense will be compiled only if unity is available */
#if HAVE_UNITY
 
namespace Clinica {

    internal class PatientLens : Unity.Lens {
    
        private ResourceManager resource_manager;
        
        private PatientsScope scope;
    
        public PatientLens (ResourceManager resources) {
            base (Config.RESOURCE_BASE + "lens/patients", "patients");
            resource_manager = resources;
            
            debug ("Starting PatientLens");
            
            search_hint = _("Search for patients");
            visible = true;
            search_in_global = false;
            
            var lens_categories = new List<Unity.Category> ();
            
            var recent_patients = new Unity.Category (_("Recently visited patients"),
                      new FileIcon (File.new_for_path ("/usr/share/unity/5/lens-nav-clinica.svg")));
            lens_categories.append (recent_patients);
            
            var cat = new Unity.Category (_("Patients"), 
                      new FileIcon (File.new_for_path ("/usr/share/unity/5/lens-nav-clinica.svg")));
            lens_categories.append (cat);
            
            categories = lens_categories;
            
            scope = new PatientsScope (resource_manager);
            add_local_scope (scope);
        }
    
    } 

}

#endif
