/*
 *   This file is part of Clinica.
 *
 *   Clinica is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   Clinica is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with Clinica.  If not, see <http://www.gnu.org/licenses/>.
 *
 *   Authors: Leonardo Robol <leo@robol.it>
 */
 
 #if HAVE_UNITY
 
namespace Clinica {

    internal class PatientsScope : Unity.Scope {
    
        private ResourceManager resource_manager;
    
        public PatientsScope (ResourceManager resources) {
            base (Config.RESOURCE_BASE + "scope/patients");
            resource_manager = resources;
            
            search_changed.connect (on_search_changed);
            activate_uri.connect (on_uri_activated);
        }
        
        private void on_search_changed (Unity.LensSearch? search, Unity.SearchType type) {
            if (search == null || search.search_string == null)
                return;
                
            string lsearch = search.search_string.down ();
                
            results_model.clear ();
            
            // Search the patients visited recently, but don't list the same patient twice. 
            List<int64?> recent_patients = new List<int64?> ();
            HashTable<int64?, int> matched_patients = new HashTable<int64?, int> (GLib.int64_hash, GLib.int_equal);
            foreach (Visit v in resource_manager.data_provider.visits ()) {
                if (recent_patients.index (v.patient.id) == -1 && lsearch in v.patient.get_complete_name ()
                   && (!matched_patients.contains (v.patient.id))) {
                    matched_patients[v.patient.id] = 1;
                    results_model.append (@"patient:$(v.patient.id)",
                        resource_manager.prefix + "/share/pixmaps/clinica.svg",
                        0, "", v.patient.get_complete_name (), "Patient", "");
                     recent_patients.append (v.patient.id);
                }
                
                if (recent_patients.length () > 5)
                    break;
            }
                
            // Search in the patients the ones that match the
            // search string specified by the user.
            foreach (Patient p in resource_manager.data_provider.patients ()) {
                if (lsearch in p.get_complete_name ().down ()) {
                    results_model.append (@"patient:$(p.id)", 
                            resource_manager.prefix + "/share/pixmaps/clinica.svg",
                            1, "text/html", 
                            p.get_complete_name (), "Patient", "");
                }
            }
        }
        
        private Unity.ActivationResponse on_uri_activated (string uri) {
            if ("patient" in uri) {
                int64 patient_id = int64.parse (uri.split (":")[1]);
                
                // Use our application wrapper that will instantiate a UserInterface
                // if one is not running yet. 
                resource_manager.application.show_visits (
                    resource_manager.data_provider.get_patient (patient_id));
                return new Unity.ActivationResponse (Unity.HandledType.HIDE_DASH);
            }
            
            return new Unity.ActivationResponse (Unity.HandledType.NOT_HANDLED);
        }
            
    }

}

#endif
