/*
 *   This file is part of Clinica.
 *
 *   Clinica is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   Clinica is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with Clinica.  If not, see <http://www.gnu.org/licenses/>.
 *
 *   Authors: Leonardo Robol <leo@robol.it>
 */
 
 namespace Clinica {
 
    [DBus (name = "org.phcteam.clinica.Service")]
    public class Service : GLib.Object {
    
        /**
         * @brief The resource manager associated to this
         * Service.
         */
        internal ResourceManager resource_manager;
    
        /**
         * @brief Return the version of clinica that is running.
         */
        public string version () {
            return Config.VERSION;
        }
        
        /**
         * @brief Return a lists of patients id whose name
         * match the given string.
         */
        public int64 [] patients_filter (string filter) {
            string lfilter = filter.down();
            int64 [] patients = {};
            foreach (var patient in resource_manager.data_provider.patients ()) {
                if (lfilter in patient.get_complete_name ().down ()) {
                    patients += patient.id;
                }
            }
            
            return patients;
        }
        
        /**
         * @brief Get the patients name associated to the given ID.
         */
        public string get_patient_name (int64 id) {
           var patient = resource_manager.data_provider.get_patient (id);
           return patient.get_complete_name (); 
        }
        
        /**
         * @brief Open the vists of the patients specified by the given
         * ID.
         */
        public void open_visits (int64 id) {
            Patient p = resource_manager.data_provider.get_patient (id);
            resource_manager.application.show_visits (p);
        }
        
        public Service (ResourceManager resources) {
            resource_manager = resources;
        }
        
    }
    
    
 }
